# KnowledgeNet

**SIGDAT 2019**: [KnowledgeNet: A Benchmark Dataset for Knowledge Base Population](https://aclanthology.org/D19-1069/)

**GitHub**: [`diffbot/knowledge-net`](https://github.com/diffbot/knowledge-net)

**License**: [CC BY-SA 4.0](https://github.com/diffbot/knowledge-net/blob/master/dataset/LICENSE-DATASET)


## Splits

Only the train set is labelled.
